@@ -19,8 +19,8 @@ describe 'FactoryGirl.lint' do
     error_message = <<-ERROR_MESSAGE.strip
 The following factories are invalid:
 
-* user
-* admin_user
+* user - Validation failed: Name can't be blank (ActiveRecord::RecordInvalid)
+* admin_user - Validation failed: Name can't be blank (ActiveRecord::RecordInvalid)
     ERROR_MESSAGE
 
     expect do
@@ -42,14 +42,24 @@ The following factories are invalid:
     expect { FactoryGirl.lint }.not_to raise_error
   end
 
-  it 'supports models which do not respond to #valid?' do
-    define_class 'Thing'
-
-    FactoryGirl.define do
-      factory :thing
+  it 'allows for selective linting' do
+    define_model 'InvalidThing', name: :string do
+      validates :name, presence: true
     end
 
-    expect(Thing.new).not_to respond_to(:valid?)
-    expect { FactoryGirl.lint }.not_to raise_error
+    define_model 'ValidThing', name: :string
+
+    FactoryGirl.define do
+      factory :valid_thing
+      factory :invalid_thing
+    end
+
+    expect do
+      only_valid_factories = FactoryGirl.factories.reject do |factory|
+        factory.name =~ /invalid/
+      end
+
+      FactoryGirl.lint only_valid_factories
+    end.not_to raise_error
   end
 end
